ArgumentParser class

Command argument parser

Constructors

ArgumentParser(List<String> arguments)

Properties

arguments → List<String>
Arguments from command params
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseArguments(YamlMap config) → Map<String, dynamic>
Provides arguments from command based on YAML fields config
parseConfigPath() → String?
Defines if config key was specified during command run
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited