Config class

Config object that provides parsed params from command

Constructors

Config(Map config, Map<String, dynamic> arguments, Iterable<FieldConfig> fields, Map extConfig)
Config.fromMap(PlatformValueProvider valueProvider, Map config, Map<String, dynamic> args)
factory

Properties

arguments → Map<String, dynamic>
Arguments from command
final
classConfigFields → Iterable<FieldConfig>
Fields, that should be exported to Dart config file
no setter
className → String
Provides config class name
no setter
config → Map
Config object from yaml file
final
createConfigClass → bool
Defines if generator should try to create Dart config file
no setter
createDotEnv → bool
Defines if generator should try to create .env file
no setter
dotEnvFields → Iterable<FieldConfig>
Fields, that should be exported to .env file
no setter
dotEnvFilePath → String
Target file for .env params
no setter
extConfig → Map
Extension config object from yaml file
final
filePath → String
Target file for generated config class
no setter
hashCode → int
The hash code for this object.
no setterinherited
ignoreForFile → Iterable<String>
no setter
imports → Iterable<String>
Collection if imports, that should be added to config class
no setter
isClassConst → bool
If class should contain const constructor
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited