FieldConfig class

Constructors

FieldConfig(PlatformValueProvider valueProvider, String name, Map field, Map extField, [String? value])

Properties

dotEnvValue → String
Value for key in .env file
no setter
extField → Map
Field configuration from YAML file
final
field → Map
Field configuration from YAML file
final
hashCode → int
The hash code for this object.
no setterinherited
isConfigField → bool
Defines if this field should be exported to Dart config file
no setter
isConst → bool
Defines if field should be const or not
no setter
isDotEnv → bool
Defines if this field should be exported to .env file
no setter
isStatic → bool
Is Field should be defined as STATIC
no setter
modifier → FieldModifier
Field modifier
no setter
name → String
Field name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Field type
no setter
value → String
Get value for config class
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited